@@ -17,6 +17,8 @@ TO DO:
 """
 
 from controlSBML.make_roadrunner import makeRoadrunner
+from controlSBML import msgs
+import controlSBML as ctl
 
 import control
 import numpy as np
@@ -74,12 +76,16 @@ class ControlBase(object):
         self.reaction_names = list(self.reduced_stoichiometry_df.columns)
         self.num_state = len(self.state_names)
         # Handle defaults
-        self.input_names = calcNames(self.reaction_names, input_names,
-              "reaction names", "inputs")
+        if input_names is None:
+            self.input_names = []
+        else:
+            self.input_names = input_names
         self.input_names = self._sortList(self.reaction_names, self.input_names)
+        self.num_input = len(self.input_names)
         self.output_names = calcNames(self.state_names, output_names,
               "states", "outputs")
         self.output_names = self._sortList(self.species_names, self.output_names)
+        self.num_output = len(self.output_names)
         # Other calculations
         self.B_df = self._makeBDF()
         self.C_df = self._makeCDF()
@@ -194,6 +200,17 @@ class ControlBase(object):
         """
         return self._makeSer(self.state_names)
 
+    @property
+    def output_ser(self):
+        """
+        Contructs vector of current state values.
+
+        Returns
+        -------
+        np.ndarray: N X 1
+        """
+        return self._makeSer(self.output_names)
+
     def _makeSer(self, names):
         """
         Contructs a Series for the names.
@@ -231,7 +248,8 @@ class ControlBase(object):
 
     def setTime(self, time):
         self.roadrunner.reset()
-        _ = self.roadrunner.simulate(0, time)
+        if time > 0.01:
+            _ = self.roadrunner.simulate(0.0, time)
 
     # FIXME: Doesn't update "sets" done to roadrunner
     def copy(self):
@@ -245,9 +263,19 @@ class ControlBase(object):
         ctlsb = self.__class__(self.model_reference,
               input_names=self.input_names,
               output_names=self.output_names)
-        ctlsb.setTime(self.roadrunner.model.getTime())
+        ctlsb.setTime(self.getTime())
         return ctlsb
 
+    def getTime(self):
+        """
+        Gets current simulation time.
+        
+        Returns
+        -------
+        float
+        """
+        return self.roadrunner.model.getTime()
+
     # TODO: More complete check of attributes?
     def equals(self, other):
         """
@@ -264,8 +292,8 @@ class ControlBase(object):
         bValue = self.antimony == other.antimony
         if IS_DEBUG:
              print("1: %d" % bValue)
-        bValue = bValue and np.isclose(self.roadrunner.model.getTime(),  \
-              other.roadrunner.model.getTime())
+        bValue = bValue and np.isclose(self.getTime(),  \
+              other.getTime())
         if IS_DEBUG:
              print("2: %d" % bValue)
         bValue = bValue and all([s1 == s2 for s1, s2
@@ -326,6 +354,8 @@ class ControlBase(object):
             value: value
         """
         for name, value in name_dct.items():
+            if isinstance(value, int):
+                value = float(value)
             self.roadrunner[name] = value
 
     @staticmethod
@@ -362,10 +392,11 @@ class ControlBase(object):
         #
         return B_df
 
-    def makeStateSpace(self, A_mat=None, B_mat=None, C_mat=None, D_mat=None):
+    def makeStateSpace(self, A_mat=None, B_mat=None,
+          C_mat=None, D_mat=None):
         """
-        Creates a control system object for the n X n jacobian. By default,
-        the D matrix is always 0.
+        Creates a state space control object for
+        the n X n jacobian. By default, the D matrix is always 0.
 
         Parameters
         ----------
@@ -404,3 +435,21 @@ class ControlBase(object):
             D_mat = np.repeat(0, nrow*ncol)
             D_mat = np.reshape(D_mat, (nrow, ncol))
         return control.StateSpace(A_mat, B_mat, C_mat, D_mat)
+
+    def makeNonlinearIOSystem(self, name, effector_dct=None):
+        """
+        Creates an object that can be used in connections with the
+        control package.
+ 
+        Parameters
+        ----------
+        name: str (name of the system)
+        effector_dct: dict (maps reaction inputs to roadrunner muteables)
+            key: str (input name)
+            value: str (name of roadrunner muteable)
+        
+        Returns
+        -------
+        controlSBML.NonelinearIOSystem
+        """
+        return ctl.NonlinearIOSystem(name, self, effector_dct=effector_dct)
