@@ -173,8 +173,6 @@ def mat2DF(mat, column_names=None, row_names=None):
             if ("NamedArray" in str(type(mat))):
                 if len(mat.rownames) > 0:
                     row_names = mat.rownames
-        if row_names is None:
-            row_names = list(range(np.shape(mat)[0]))
         df = pd.DataFrame(mat, columns=column_names, index=row_names)
     return df
 
@@ -188,8 +186,9 @@ def ppMat(mat, column_names=None, row_names=None, is_print=True):
     column_names: list-str
     row_names: list-str
     """
+    df = mat2DF(mat, column_names=column_names, row_names=row_names)
     if is_print:
-        print(mat2DF(mat(column_names=column_names, row_names=row_names)))
+        print(df)
 
 def plotMat(mat, column_names=None, row_names=None, is_plot=True, **kwargs):
     """
